@@ -1,18 +1,21 @@
 """
 """
 
-from ._binom_confint import compute_confidence_interval, list_confidence_interval_types
+from ._binom_confint import (
+    compute_confidence_interval,
+    list_confidence_interval_methods,
+)
 from ._diff_binom_confint import (
     compute_difference_confidence_interval,
-    list_difference_confidence_interval_types,
+    list_difference_confidence_interval_methods,
 )
 from .version import __version__
 
 
 __all__ = [
     "compute_confidence_interval",
-    "list_confidence_interval_types",
+    "list_confidence_interval_methods",
     "compute_difference_confidence_interval",
-    "list_difference_confidence_interval_types",
+    "list_difference_confidence_interval_methods",
     "__version__",
 ]
